import React, { useState } from "react";

function CountrySelect({ name, id, handler, value, options, padding = "p-3" }) {
  const [isOpen, setIsOpen] = useState(false);

  return (
    <div
      className={`select_box flex relative    bg-white  cursor-pointer transition-all duration-500 w-full`}
    >
      <div className={isOpen ? "z-50 w-full " : "z-0 w-full"}>
        <div
          onClick={() => setIsOpen(!isOpen)}
          className={` ${
            isOpen ? "block" : "hidden"
          } w-full h-full fixed    bg-opacity-30 top-0 left-0 `}
        />
        <div>
          <div
            className={`lg:min-w-[200px] min-w-[140px] gap-1 flex justify-between  bg-transparent outline-none focus:outline-none ${padding} text-sm text-dark-300 border-primary-100 ${
              isOpen
                ? " border-t border-l border-r rounded-t z-20 "
                : "border  rounded z-10"
            }`}
            onClick={() => setIsOpen(!isOpen)}
          >
            <p name={name} id={id} className=" line-clamp-1">
              {options.find((country) => country?.id === Number(value))?.name ||
                "Select a country"}
            </p>
            <svg
              className=" "
              xmlns="http://www.w3.org/2000/svg"
              width="24"
              height="24"
              viewBox="0 0 24 24"
              fill="none"
            >
              <rect width="24" height="24" rx="2" fill="#8037A9" />
              <path
                d="M18.7098 8.20998C18.6169 8.11625 18.5063 8.04186 18.3844 7.99109C18.2625 7.94032 18.1318 7.91418 17.9998 7.91418C17.8678 7.91418 17.7371 7.94032 17.6152 7.99109C17.4934 8.04186 17.3828 8.11625 17.2898 8.20998L12.7098 12.79C12.6169 12.8837 12.5063 12.9581 12.3844 13.0089C12.2625 13.0596 12.1318 13.0858 11.9998 13.0858C11.8678 13.0858 11.7371 13.0596 11.6152 13.0089C11.4934 12.9581 11.3828 12.8837 11.2898 12.79L6.70982 8.20998C6.61685 8.11625 6.50625 8.04186 6.38439 7.99109C6.26253 7.94032 6.13183 7.91418 5.99982 7.91418C5.8678 7.91418 5.7371 7.94032 5.61524 7.99109C5.49338 8.04186 5.38278 8.11625 5.28982 8.20998C5.10356 8.39735 4.99902 8.6508 4.99902 8.91498C4.99902 9.17917 5.10356 9.43262 5.28982 9.61998L9.87982 14.21C10.4423 14.7718 11.2048 15.0873 11.9998 15.0873C12.7948 15.0873 13.5573 14.7718 14.1198 14.21L18.7098 9.61998C18.8961 9.43262 19.0006 9.17917 19.0006 8.91498C19.0006 8.6508 18.8961 8.39735 18.7098 8.20998Z"
                fill="white"
              />
            </svg>
          </div>
          <div
            className={`${
              isOpen ? `block z-10 ` : "hidden z-0 "
            } transition-all duration-500 origin-top openAnim absolute w-full border-primary-100 border-b border-l border-r rounded-b bg-white text-dark-300 text-sm`}
          >
            {options.map((option, index) => (
              <p
                key={option}
                value={"option" + index}
                onClick={() => {
                  setIsOpen(!isOpen);
                  handler(option.id);
                }}
                className={`hover:bg-[#FDF9FF] ${padding} py-2`}
              >
                {option.name}
              </p>
            ))}
          </div>
        </div>
        <label htmlFor={id} className="absolute right-2 z-0 top-[10px]"></label>
      </div>
    </div>
  );
}

export default CountrySelect;
